"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = getAuthorizationUrl;

var _client = require("../oauth/client");

var _clientLegacy = require("../oauth/client-legacy");

var _stateHandler = require("../oauth/state-handler");

var _pkceHandler = require("../oauth/pkce-handler");

async function getAuthorizationUrl(req, res) {
  var _provider$version;

  const {
    logger
  } = req.options;
  const provider = req.options.provider;
  const params = {
    scope: provider.scope,
    ...provider.params,
    ...req.query
  };

  if ((_provider$version = provider.version) !== null && _provider$version !== void 0 && _provider$version.startsWith("1.")) {
    try {
      const tokens = await _clientLegacy.oAuth1Client.getOAuthRequestToken(params);
      const url = `${provider.authorizationUrl}?${new URLSearchParams({
        oauth_token: tokens.oauth_token,
        oauth_token_secret: tokens.oauth_token_secret,
        ...tokens.params
      })}`;
      logger.debug("GET_AUTHORIZATION_URL", {
        url
      });
      return url;
    } catch (error) {
      logger.error("GET_AUTHORIZATION_URL_ERROR", error);
      throw error;
    }
  }

  const client = await (0, _client.openidClient)(req.options);
  const pkce = await (0, _pkceHandler.createPKCE)(req, res);
  return client.authorizationUrl({ ...params,
    ...pkce,
    state: (0, _stateHandler.createState)(req)
  });
}